==> linuxconf-1.26r2.src.tar.gz: linuxconf-1.26r2/modules/inetdconf/inetdconf.pm <==
/* _dict.cc 11/12/1999 11.34.02 */
/* etcprotocol.cc 03/02/2000 13.36.32 */
PRIVATE void ETCPROTOCOL::init (void);
PUBLIC ETCPROTOCOL::ETCPROTOCOL (const char *_protocol_name);
PUBLIC ETCPROTOCOL::ETCPROTOCOL (void);
PUBLIC ETCPROTOCOL *ETCPROTOCOLLIST::getitem (int no)const;
PUBLIC ETCPROTOCOL *ETCPROTOCOLLIST::getitem (const char *_protocol_name)const;
PUBLIC ETCPROTOCOL *ETCPROTOCOLLIST::getitem_alias (const char *_service_name)
	const;
PUBLIC ETCPROTOCOLLIST::ETCPROTOCOLLIST (void);
PRIVATE char *ETCPROTOCOLLIST::next_word (char *d,
	 char *s,
	 int size);
PRIVATE int ETCPROTOCOLLIST::valid_number (char *word,
	 ETCPROTOCOL *etcprotocol);
PRIVATE void ETCPROTOCOLLIST::valid_aliases (char *word,
	 ETCPROTOCOL *etcprotocol);
PUBLIC void ETCPROTOCOLLIST::add_protocol (int line_number,
	 VIEWITEM *item);
PUBLIC void ETCPROTOCOLLIST::read (void);
PUBLIC int ETCPROTOCOLLIST::edit (void);
/* etcservice.cc 15/02/2000 13.34.50 */
PRIVATE void ETCSERVICE::init (void);
PUBLIC ETCSERVICE::ETCSERVICE (const char *_service_name);
PUBLIC ETCSERVICE::ETCSERVICE (void);
PUBLIC int ETCSERVICE::write (int button);
PRIVATE void ETCSERVICE::modify_service (VIEWITEM *item);
PUBLIC int ETCSERVICE::edit (void);
PRIVATE int ETCSERVICE::input_error (void);
PUBLIC ETCSERVICE *ETCSERVICELIST::getitem (int no)const;
PUBLIC ETCSERVICE *ETCSERVICELIST::getitem (const char *_service_name)const;
PUBLIC ETCSERVICE *ETCSERVICELIST::getitem (const char *_protocol,
	 int _port)const;
PUBLIC ETCSERVICE *ETCSERVICELIST::getitem_alias (const char *_service_name)
	const;
PUBLIC ETCSERVICE *ETCSERVICELIST::getitem_service (const char *_service)const;
PUBLIC ETCSERVICELIST::ETCSERVICELIST (void);
PRIVATE char *ETCSERVICELIST::next_word (char *d, char *s, int size);
PRIVATE int ETCSERVICELIST::valid_port_protocol (char *word,
	 ETCSERVICE *etcservice);
PRIVATE void ETCSERVICELIST::valid_aliases (char *word,
	 ETCSERVICE *etcservice);
PUBLIC void ETCSERVICELIST::add_service (int line_number,
	 VIEWITEM *item);
PUBLIC void ETCSERVICELIST::read (void);
PUBLIC int ETCSERVICELIST::edit (void);
/* fwedit.cc 28/09/2000 20.41.32 */
PUBLIC DAEMON_DIALD::DAEMON_DIALD (void);
PUBLIC PROC *DAEMON_DIALD::getdaemonprocess (void);
PUBLIC FW::FW (void);
PUBLIC FW::~FW (void);
PUBLIC int FW::firewall_setup (void);
PUBLIC int FW::internet_route (void);
PUBLIC void FW::daemon_config_file (void);
PRIVATE void FW::write_start_firewall_forward (FILE_CFG *fout,
	 const char *ipchains);
PUBLIC int FW::write (void);
PRIVATE void FW::check_status (void);
PRIVATE void FW::append_to_dialog (DIALOG *dia, FWPORT *fwport);
PUBLIC int FW::edit (void);
PUBLIC int FW::input_error (void);
PUBLIC DAEMON_FIREWALL::DAEMON_FIREWALL (void);
PUBLIC PROC *DAEMON_FIREWALL::getdaemonprocess (void);
PUBLIC int DAEMON_FIREWALL::killdaemon (void);
PUBLIC int DAEMON_FIREWALL::startdaemon (void);
/* fwport.cc 27/03/2000 11.56.18 */
FWPORT::FWPORT (void);
FWPORTLIST::FWPORTLIST (void);
PRIVATE void FWPORTLIST::tcp_do_one (int lnr, const char *line);
PRIVATE void FWPORTLIST::udp_do_one (int lnr, const char *line);
PRIVATE int FWPORTLIST::getlist_tcp (void);
PRIVATE int FWPORTLIST::getlist_udp (void);
PUBLIC void FWPORTLIST::sort (void);
PUBLIC void FWPORTLIST::update_from_db (void);
PUBLIC void FWPORTLIST::read (void);
PUBLIC FWPORT *FWPORTLIST::getitem (int no)const;
/* hostsallow.cc 12/04/2001 17.02.54 */
PUBLIC MYDATA::MYDATA (int path, CONFIG_FILE *f);
PUBLIC MYDATA::~MYDATA (void);
PRIVATE void HOSTSALLOW::init (void);
PUBLIC HOSTSALLOW::HOSTSALLOW (const char *_service);
PUBLIC HOSTSALLOW::HOSTSALLOW (void);
PUBLIC int HOSTSALLOW::write (int button, MYDATA *mydata);
PRIVATE void HOSTSALLOW::modify_service (VIEWITEM *item);
PUBLIC int HOSTSALLOW::edit (MYDATA *mydata);
PRIVATE int HOSTSALLOW::input_error (void);
PUBLIC HOSTSALLOW *HOSTSALLOWLIST::getitem (int no)const;
PUBLIC HOSTSALLOW *HOSTSALLOWLIST::getitem (const char *_service)const;
PUBLIC HOSTSALLOWLIST::HOSTSALLOWLIST (void);
PRIVATE char *HOSTSALLOWLIST::next_word (char *d, char *s, int size);
PUBLIC void HOSTSALLOWLIST::add_service (int line_number,
	 VIEWITEM *item);
PUBLIC void HOSTSALLOWLIST::read (MYDATA *mydata);
PUBLIC int HOSTSALLOWLIST::edit (MYDATA *mydata);
/* inetdconf.cc 28/08/2000 18.12.38 */
PUBLIC MODULE_inetdconf::MODULE_inetdconf (void);
PUBLIC void MODULE_inetdconf::setmenu (DIALOG&dia,
	 MENU_CONTEXT context);
PUBLIC int MODULE_inetdconf::domenu (MENU_CONTEXT context,
	 const char *key);
PUBLIC int MODULE_inetdconf::dohtml (const char *key);
PUBLIC int MODULE_inetdconf::message (const char *msg,
	 int argc,
	 const char *argv[]);
PUBLIC void MODULE_inetdconf::usage (SSTRINGS&tb);
PUBLIC int MODULE_inetdconf::execmain (int argc, char *argv[], bool);
PUBLIC int MODULE_inetdconf::probe (int level,
	 int target,
	 bool simulation);
/* inetdconf_api.cc 12/04/2001 17.02.54 */
/* inetdconfedit.cc 12/04/2001 17.02.54 */
PRIVATE void INETDCONF::init (void);
PUBLIC INETDCONF::INETDCONF (INETDCONFLIST *_inetdconflist);
PUBLIC int INETDCONF::write (int button);
PRIVATE int INETDCONF::write_xinetd (int button);
PRIVATE int INETDCONF::set_enabled_disabled (void);
PRIVATE int INETDCONF::write_xinetd_service (FILE *fpw);
PRIVATE void INETDCONF::put_string (FILE *fpw,
	 const char *attribute,
	 const char *value);
PRIVATE void INETDCONF::put_integer (FILE *fpw,
	 const char *attribute,
	 int value);
PRIVATE int INETDCONF::write_inetd (int button);
PRIVATE void INETDCONF::inetd_modify_service (VIEWITEM *item);
PUBLIC int INETDCONF::edit (INETDCONFLIST *list);
PRIVATE void INETDCONF::set_attribute_type (void);
PRIVATE void INETDCONF::set_attribute_flags (void);
PRIVATE void INETDCONF::set_attribute_log_type (void);
PRIVATE void INETDCONF::set_attribute_log_on_success (void);
PRIVATE void INETDCONF::set_attribute_log_on_failure (void);
PRIVATE void INETDCONF::add_xinetd_extensions (DIALOG *dia);
PUBLIC int INETDCONF::edit (void);
PRIVATE void INETDCONF::present (char *buf1,
	 int size1,
	 char *buf2,
	 int size2);
PRIVATE const char *INETDCONF::get_server_path (void);
PUBLIC int INETDCONF::server_path_error (char *text, int size);
PRIVATE int INETDCONF::input_error (void);
PUBLIC void INETDCONFLIST::sort (void);
PUBLIC INETDCONF *INETDCONFLIST::getitem (int no)const;
PUBLIC INETDCONF *INETDCONFLIST::getitem (const char *_service_name)const;
PUBLIC INETDCONFLIST::INETDCONFLIST (void);
PRIVATE int INETDCONFLIST::valid_etcservice (char *word,
	 INETDCONF *inetdconf);
PRIVATE int INETDCONFLIST::valid_socket_type (char *word,
	 INETDCONF *inetdconf);
PRIVATE int INETDCONFLIST::valid_protocol (char *word,
	 INETDCONF *inetdconf);
PRIVATE int INETDCONFLIST::valid_multi_max (char *word,
	 INETDCONF *inetdconf);
PRIVATE int INETDCONFLIST::valid_user_group (char *word,
	 INETDCONF *inetdconf);
PRIVATE int INETDCONFLIST::valid_path (char *word,
	 INETDCONF *inetdconf);
PUBLIC void INETDCONFLIST::read (void);
PRIVATE void INETDCONFLIST::read_xinetd (void);
PRIVATE void INETDCONFLIST::scan_directory (char *directory,
	 const char *file);
PRIVATE void INETDCONFLIST::scan_file (const char *file);
PRIVATE void INETDCONFLIST::set_enabled (INETDCONF *inetdconf);
PRIVATE void INETDCONFLIST::add_attribute (SSTRING *string,
	 char *myOperator,
	 char *myValue);
PRIVATE void INETDCONFLIST::cat_attribute (SSTRING *string,
	 char *myValue);
PRIVATE void INETDCONFLIST::read_inetd (void);
PRIVATE void INETDCONFLIST::add_service_inetd (int line_number,
	 VIEWITEM *item);
PUBLIC int INETDCONFLIST::edit (void);
/* servicectl_api.cc 12/04/2001 17.02.54 */
PUBLIC SERVICE_INETDCONF::SERVICE_INETDCONF (const char *_name,
	 const char *_desc,
	 int _state);
PUBLIC int SERVICE_INETDCONF::edit (void);
PUBLIC const char *SERVICE_INETDCONF::getconfstatus (void);
PUBLIC const char *SERVICE_INETDCONF::getrunstatus (void);
PUBLIC void SERVICE_INETDCONF::showstatus (void);
PUBLIC int SERVICE_INETDCONF::control (SERVICE_OPER oper);

==> linuxconf-1.33r3.src.tar.gz: linuxconf-1.33r3/modules/inetdconf/inetdconf.pm <==
/* _dict.cc 11/12/1999 11.34.02 */
/* etcprotocol.cc 03/02/2000 13.36.32 */
PRIVATE void ETCPROTOCOL::init (void);
PUBLIC ETCPROTOCOL::ETCPROTOCOL (const char *_protocol_name);
PUBLIC ETCPROTOCOL::ETCPROTOCOL (void);
PUBLIC ETCPROTOCOL *ETCPROTOCOLLIST::getitem (int no)const;
PUBLIC ETCPROTOCOL *ETCPROTOCOLLIST::getitem (const char *_protocol_name)const;
PUBLIC ETCPROTOCOL *ETCPROTOCOLLIST::getitem_alias (const char *_service_name)
	const;
PUBLIC ETCPROTOCOLLIST::ETCPROTOCOLLIST (void);
PRIVATE char *ETCPROTOCOLLIST::next_word (char *d,
	 char *s,
	 int size);
PRIVATE int ETCPROTOCOLLIST::valid_number (char *word,
	 ETCPROTOCOL *etcprotocol);
PRIVATE void ETCPROTOCOLLIST::valid_aliases (char *word,
	 ETCPROTOCOL *etcprotocol);
PUBLIC void ETCPROTOCOLLIST::add_protocol (int line_number,
	 VIEWITEM *item);
PUBLIC void ETCPROTOCOLLIST::read (void);
PUBLIC int ETCPROTOCOLLIST::edit (void);
/* etcservice.cc 15/02/2000 13.34.50 */
PRIVATE void ETCSERVICE::init (void);
PUBLIC ETCSERVICE::ETCSERVICE (const char *_service_name);
PUBLIC ETCSERVICE::ETCSERVICE (void);
PUBLIC int ETCSERVICE::write (int button);
PRIVATE void ETCSERVICE::modify_service (VIEWITEM *item);
PUBLIC int ETCSERVICE::edit (void);
PRIVATE int ETCSERVICE::input_error (void);
PUBLIC ETCSERVICE *ETCSERVICELIST::getitem (int no)const;
PUBLIC ETCSERVICE *ETCSERVICELIST::getitem (const char *_service_name)const;
PUBLIC ETCSERVICE *ETCSERVICELIST::getitem (const char *_protocol,
	 int _port)const;
PUBLIC ETCSERVICE *ETCSERVICELIST::getitem_alias (const char *_service_name)
	const;
PUBLIC ETCSERVICE *ETCSERVICELIST::getitem_service (const char *_service)const;
PUBLIC ETCSERVICELIST::ETCSERVICELIST (void);
PRIVATE char *ETCSERVICELIST::next_word (char *d, char *s, int size);
PRIVATE int ETCSERVICELIST::valid_port_protocol (char *word,
	 ETCSERVICE *etcservice);
PRIVATE void ETCSERVICELIST::valid_aliases (char *word,
	 ETCSERVICE *etcservice);
PUBLIC void ETCSERVICELIST::add_service (int line_number,
	 VIEWITEM *item);
PUBLIC void ETCSERVICELIST::read (void);
PUBLIC int ETCSERVICELIST::edit (void);
/* fwedit.cc 28/09/2000 20.41.32 */
PUBLIC DAEMON_DIALD::DAEMON_DIALD (void);
PUBLIC PROC *DAEMON_DIALD::getdaemonprocess (void);
PUBLIC FW::FW (void);
PUBLIC FW::~FW (void);
PUBLIC int FW::firewall_setup (void);
PUBLIC int FW::internet_route (void);
PUBLIC void FW::daemon_config_file (void);
PRIVATE void FW::write_start_firewall_forward (FILE_CFG *fout,
	 const char *ipchains);
PUBLIC int FW::write (void);
PRIVATE void FW::check_status (void);
PRIVATE void FW::append_to_dialog (DIALOG *dia, FWPORT *fwport);
PUBLIC int FW::edit (void);
PUBLIC int FW::input_error (void);
PUBLIC DAEMON_FIREWALL::DAEMON_FIREWALL (void);
PUBLIC PROC *DAEMON_FIREWALL::getdaemonprocess (void);
PUBLIC int DAEMON_FIREWALL::killdaemon (void);
PUBLIC int DAEMON_FIREWALL::startdaemon (void);
/* fwport.cc 27/03/2000 11.56.18 */
FWPORT::FWPORT (void);
FWPORTLIST::FWPORTLIST (void);
PRIVATE void FWPORTLIST::tcp_do_one (int lnr, const char *line);
PRIVATE void FWPORTLIST::udp_do_one (int lnr, const char *line);
PRIVATE int FWPORTLIST::getlist_tcp (void);
PRIVATE int FWPORTLIST::getlist_udp (void);
PUBLIC void FWPORTLIST::sort (void);
PUBLIC void FWPORTLIST::update_from_db (void);
PUBLIC void FWPORTLIST::read (void);
PUBLIC FWPORT *FWPORTLIST::getitem (int no)const;
/* hostsallow.cc 12/04/2001 17.02.54 */
PUBLIC MYDATA::MYDATA (int path, CONFIG_FILE *f);
PUBLIC MYDATA::~MYDATA (void);
PRIVATE void HOSTSALLOW::init (void);
PUBLIC HOSTSALLOW::HOSTSALLOW (const char *_service);
PUBLIC HOSTSALLOW::HOSTSALLOW (void);
PUBLIC int HOSTSALLOW::write (int button, MYDATA *mydata);
PRIVATE void HOSTSALLOW::modify_service (VIEWITEM *item);
PUBLIC int HOSTSALLOW::edit (MYDATA *mydata);
PRIVATE int HOSTSALLOW::input_error (void);
PUBLIC HOSTSALLOW *HOSTSALLOWLIST::getitem (int no)const;
PUBLIC HOSTSALLOW *HOSTSALLOWLIST::getitem (const char *_service)const;
PUBLIC HOSTSALLOWLIST::HOSTSALLOWLIST (void);
PRIVATE char *HOSTSALLOWLIST::next_word (char *d, char *s, int size);
PUBLIC void HOSTSALLOWLIST::add_service (int line_number,
	 VIEWITEM *item);
PUBLIC void HOSTSALLOWLIST::read (MYDATA *mydata);
PUBLIC int HOSTSALLOWLIST::edit (MYDATA *mydata);
/* inetdconf.cc 28/08/2000 18.12.38 */
PUBLIC MODULE_inetdconf::MODULE_inetdconf (void);
PUBLIC void MODULE_inetdconf::setmenu (DIALOG&dia,
	 MENU_CONTEXT context);
PUBLIC int MODULE_inetdconf::domenu (MENU_CONTEXT context,
	 const char *key);
PUBLIC int MODULE_inetdconf::dohtml (const char *key);
PUBLIC int MODULE_inetdconf::message (const char *msg,
	 int argc,
	 const char *argv[]);
PUBLIC void MODULE_inetdconf::usage (SSTRINGS&tb);
PUBLIC int MODULE_inetdconf::execmain (int argc, char *argv[], bool);
PUBLIC int MODULE_inetdconf::probe (int level,
	 int target,
	 bool simulation);
/* inetdconf_api.cc 12/04/2001 17.02.54 */
/* inetdconfedit.cc 25/10/2002 14.46.54 */
PRIVATE void INETDCONF::init (void);
PUBLIC INETDCONF::INETDCONF (INETDCONFLIST *_inetdconflist);
PUBLIC int INETDCONF::write (int button);
PRIVATE int INETDCONF::write_xinetd (int button);
PRIVATE int INETDCONF::set_enabled_disabled (void);
PRIVATE int INETDCONF::write_xinetd_service (FILE_CFG *fpw);
PRIVATE void INETDCONF::put_string (FILE_CFG *fpw,
	 const char *attribute,
	 const char *value);
PRIVATE void INETDCONF::put_integer (FILE *fpw,
	 const char *attribute,
	 int value);
PRIVATE int INETDCONF::write_inetd (int button);
PRIVATE void INETDCONF::inetd_modify_service (VIEWITEM *item);
PUBLIC int INETDCONF::edit (INETDCONFLIST *list);
PRIVATE void INETDCONF::set_attribute_type (void);
PRIVATE void INETDCONF::set_attribute_flags (void);
PRIVATE void INETDCONF::set_attribute_log_type (void);
PRIVATE void INETDCONF::set_attribute_log_on_success (void);
PRIVATE void INETDCONF::set_attribute_log_on_failure (void);
PRIVATE void INETDCONF::add_xinetd_extensions (DIALOG *dia);
PUBLIC int INETDCONF::edit (void);
PRIVATE void INETDCONF::present (char *buf1,
	 int size1,
	 char *buf2,
	 int size2);
PRIVATE const char *INETDCONF::get_server_path (void);
PUBLIC int INETDCONF::server_path_error (char *text, int size);
PRIVATE int INETDCONF::input_error (void);
PUBLIC void INETDCONFLIST::sort (void);
PUBLIC INETDCONF *INETDCONFLIST::getitem (int no)const;
PUBLIC INETDCONF *INETDCONFLIST::getitem (const char *_service_name)const;
PUBLIC INETDCONFLIST::INETDCONFLIST (void);
PRIVATE int INETDCONFLIST::valid_etcservice (char *word,
	 INETDCONF *inetdconf);
PRIVATE int INETDCONFLIST::valid_socket_type (char *word,
	 INETDCONF *inetdconf);
PRIVATE int INETDCONFLIST::valid_protocol (char *word,
	 INETDCONF *inetdconf);
PRIVATE int INETDCONFLIST::valid_multi_max (char *word,
	 INETDCONF *inetdconf);
PRIVATE int INETDCONFLIST::valid_user_group (char *word,
	 INETDCONF *inetdconf);
PRIVATE int INETDCONFLIST::valid_path (char *word,
	 INETDCONF *inetdconf);
PUBLIC void INETDCONFLIST::read (void);
PRIVATE void INETDCONFLIST::read_xinetd (void);
PRIVATE void INETDCONFLIST::scan_directory (char *directory,
	 const char *file);
PRIVATE void INETDCONFLIST::scan_file (const char *file);
PRIVATE void INETDCONFLIST::set_enabled (INETDCONF *inetdconf);
PRIVATE void INETDCONFLIST::add_attribute (SSTRING *string,
	 char *myOperator,
	 char *myValue);
PRIVATE void INETDCONFLIST::cat_attribute (SSTRING *string,
	 char *myValue);
PRIVATE void INETDCONFLIST::read_inetd (void);
PRIVATE void INETDCONFLIST::add_service_inetd (int line_number,
	 VIEWITEM *item);
PUBLIC int INETDCONFLIST::edit (void);
/* servicectl_api.cc 12/04/2001 17.03.44 */
PUBLIC SERVICE_INETDCONF::SERVICE_INETDCONF (const char *_name,
	 const char *_desc,
	 int _state);
PUBLIC int SERVICE_INETDCONF::edit (void);
PUBLIC const char *SERVICE_INETDCONF::getconfstatus (void);
PUBLIC const char *SERVICE_INETDCONF::getrunstatus (void);
PUBLIC void SERVICE_INETDCONF::showstatus (void);
PUBLIC int SERVICE_INETDCONF::control (SERVICE_OPER oper);
